package com.fs.app.controller;

import com.fs.common.core.domain.R;
import com.fs.common.core.domain.ResponseResult;
import com.fs.course.param.newfs.FsUserCourseListParam;
import com.fs.course.param.newfs.UserCourseVideoPageParam;
import com.fs.course.service.IFsUserCourseService;
import com.fs.course.service.IFsUserCourseVideoService;
import com.fs.course.vo.FsCourseAnalysisVO;
import com.fs.course.vo.FsUserCourseListPVO;
import com.fs.course.vo.newfs.FsUserCourseListVO;
import com.fs.course.vo.newfs.FsUserCourseVideoDetailsVO;
import com.fs.course.vo.newfs.FsUserCourseVideoPageListVO;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.List;
import java.util.Map;


@Api("课程库相关接口")
@RestController
@RequestMapping("/app/fs/course")
@Slf4j
public class FsUserCourseVideoController extends AppBaseController {

    @Autowired
    private IFsUserCourseVideoService fsUserCourseVideoService;

    @Autowired
    private IFsUserCourseService fsUserCourseService;

    @GetMapping("/pageList")
    @ApiOperation("课程分页列表")
    public ResponseResult<PageInfo<FsUserCourseVideoPageListVO>> list(UserCourseVideoPageParam param) {
        PageHelper.startPage(param.getPageNum(), param.getPageSize());
        List<FsUserCourseVideoPageListVO> list = fsUserCourseVideoService.pageListCourseVideo(param);
        PageInfo<FsUserCourseVideoPageListVO> pageInfo = new PageInfo<>(list);
        return ResponseResult.ok(pageInfo);
    }

    @ApiOperation("课程视频详情")
    @GetMapping(value = "/videoDetails")
    public ResponseResult<FsUserCourseVideoDetailsVO> getVideoDetails(Long videoId) {
        return fsUserCourseVideoService.getVideoDetails(videoId);
    }

    @GetMapping("/courseList")
    @ApiOperation("获取课程下拉列表")
    public ResponseResult<PageInfo<FsUserCourseListVO>> getAllCompanyUser(FsUserCourseListParam param) {
        PageHelper.startPage(param.getPageNum(), param.getPageSize());
        param.setCompanyId(getCompanyId());
        List<FsUserCourseListVO> fsUserCourseList = fsUserCourseService.getFsUserCourseList(param);
        PageInfo<FsUserCourseListVO> pageInfo = new PageInfo<>(fsUserCourseList);
        return ResponseResult.ok(pageInfo);
    }

    @ApiOperation("课程分析")
    @GetMapping("/courseAnalysis")
    public R courseAnalysis(@RequestParam(required = false) Long courseId,
                            @RequestParam(required = false) Integer status,
                            @RequestParam(required = false, value = "true") Boolean isToday,
                            @RequestParam(required = false, defaultValue = "1") Integer pageNum,
                            @RequestParam(required = false, defaultValue = "10") Integer pageSize) {

        Map<String,Object> params = new HashMap<>();
        params.put("courseId", courseId);
        params.put("companyId", getCompanyId());
        params.put("isToday", isToday);
        params.put("status", status);

        // TODO: 查询课程
        PageHelper.startPage(pageNum, pageSize);
        List<FsCourseAnalysisVO> list = fsUserCourseVideoService.getCourseAnalysisByMap(params);
        return R.ok().put("data", new PageInfo<>(list));
    }
}
