package com.fs.company.service.impl;

import java.util.Collections;
import java.util.List;
import java.util.stream.Collectors;

import com.fs.common.utils.DateUtils;
import com.fs.common.utils.StringUtils;
import com.fs.company.domain.CompanyUser;
import com.fs.company.mapper.CompanyUserMapper;
import com.fs.store.param.h5.TagListParam;
import com.fs.store.vo.h5.CompanyUserTagListVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.company.mapper.CompanyTagUserMapper;
import com.fs.company.domain.CompanyTagUser;
import com.fs.company.service.ICompanyTagUserService;

/**
 * companyService业务层处理
 *
 * @author fs
 * @date 2025-04-02
 */
@Service
public class CompanyTagUserServiceImpl implements ICompanyTagUserService
{
    @Autowired
    private CompanyTagUserMapper companyTagUserMapper;

    @Autowired
    private CompanyUserMapper  companyUserMapper;

    /**
     * 查询company
     *
     * @param id companyID
     * @return company
     */
    @Override
    public CompanyTagUser selectCompanyTagUserById(Long id)
    {
        return companyTagUserMapper.selectCompanyTagUserById(id);
    }

    /**
     * 查询company列表
     *
     * @param companyTagUser company
     * @return company
     */
    @Override
    public List<CompanyTagUser> selectCompanyTagUserList(CompanyTagUser companyTagUser)
    {
        return companyTagUserMapper.selectCompanyTagUserList(companyTagUser);
    }

    /**
     * 新增company
     *
     * @param companyTagUser company
     * @return 结果
     */
    @Override
    public int insertCompanyTagUser(CompanyTagUser companyTagUser)
    {
        companyTagUser.setCreateTime(DateUtils.getNowDate());
        return companyTagUserMapper.insertCompanyTagUser(companyTagUser);
    }

    /**
     * 修改company
     *
     * @param companyTagUser company
     * @return 结果
     */
    @Override
    public int updateCompanyTagUser(CompanyTagUser companyTagUser)
    {
        return companyTagUserMapper.updateCompanyTagUser(companyTagUser);
    }

    /**
     * 批量删除company
     *
     * @param ids 需要删除的companyID
     * @return 结果
     */
    @Override
    public int deleteCompanyTagUserByIds(Long[] ids)
    {
        return companyTagUserMapper.deleteCompanyTagUserByIds(ids);
    }

    /**
     * 删除company信息
     *
     * @param id companyID
     * @return 结果
     */
    @Override
    public int deleteCompanyTagUserById(Long id)
    {
        return companyTagUserMapper.deleteCompanyTagUserById(id);
    }

    @Override
    public List<CompanyUserTagListVO> getTagList(TagListParam param) {
        String[] keywords = new String[0];
        if (param != null) {
            if (StringUtils.isNotEmpty(param.getKeyword())) {
                keywords = param.getKeyword().split(",");
            }
        }
        //获取所有销售
        List<CompanyUser> companyUsers = companyUserMapper.selectAllCompanyUserByParentId(param != null ? param.getUserId() : null);
        List<Long> userIds = Collections.emptyList();
        if(companyUsers != null && !companyUsers.isEmpty()){
            userIds = companyUsers.stream().map(CompanyUser::getUserId).collect(Collectors.toList());
        }

        return companyTagUserMapper.getTagList(param, keywords, userIds);
    }
}
