package com.fs.store.service;

import java.util.List;
import java.util.Map;

import com.fs.common.core.domain.R;
import com.fs.common.core.page.TableDataInfo;
import com.fs.company.vo.CompanyQueryVo;
import com.fs.qw.param.QwFsUserParam;
import com.fs.qw.vo.QwFsUserVO;
import com.fs.store.domain.FsStoreOrder;
import com.fs.store.domain.FsStoreOrderItem;
import com.fs.store.domain.FsUser;
import com.fs.store.dto.FsUserTransferParamDTO;
import com.fs.store.param.SelectCusListPageParam;
import com.fs.store.param.h5.FsUserPageListParam;
import com.fs.store.vo.FSUserVO;
import com.fs.store.vo.FsCompanyUserListQueryVO;
import com.fs.store.vo.FsUserTuiVO;
import com.fs.store.vo.h5.FsUserPageListVO;
import com.fs.store.vo.h5.UserDetailsVO;
import com.fs.store.vo.h5.UserListPageVO;
import com.fs.store.vo.h5.*;

import java.util.List;

/**
 * 用户Service接口
 *
 * @author fs
 * @date 2022-03-15
 */
public interface IFsUserService
{
    /**
     * 查询用户
     *
     * @param userId 用户ID
     * @return 用户
     */
    public FsUser selectFsUserById(Long userId);

    /**

     * 查询用户
     *
     * @param userId 用户ID
     * @return FSUserVO
     */
    public FSUserVO selectFsUserByUserId(Long userId);

    /**
     * 查询用户列表
     *
     * @param fsUser 用户
     * @return 用户集合
     */
    public List<FsUser> selectFsUserList(FsUser fsUser);

    /**
     * 查询用户列表
     *
     * @param fsUser 用户
     * @return 用户集合
     */
    public List<FSUserVO> selectFsUserVOList(FsUser fsUser);

    /**
     * 新增用户
     *
     * @param fsUser 用户
     * @return 结果
     */
    public int insertFsUser(FsUser fsUser);

    /**
     * 修改用户
     *
     * @param fsUser 用户
     * @return 结果
     */
    public int updateFsUser(FsUser fsUser);

    /**
     * 批量删除用户
     *
     * @param userIds 需要删除的用户ID
     * @return 结果
     */
    public int deleteFsUserByIds(Long[] userIds);

    /**
     * 删除用户信息
     *
     * @param userId 用户ID
     * @return 结果
     */
    public int deleteFsUserById(Long userId);

    int decIntegral( Long uid,  double usedIntegral);

    int incPayCount(Long userId);

    FsUser selectFsUserByPhone(String phone);

    TableDataInfo selectCusListPage(SelectCusListPageParam param);

    List<FsCompanyUserListQueryVO> selectFsCompanyUserListQuery(FsUser fsUser);

    List<FsUserTuiVO> selectFsUserTuiList(String userId);

    Long selectFsUserCount(int type,Long companyId);

    void addTuiMoney(FsStoreOrder order, List<FsStoreOrderItem> items);

    void subTuiMoney(FsStoreOrder order);

    void addMoney(FsStoreOrder order);

    FsUser selectFsUserByMaOpenId(String openid);

    FsUser selectFsUserByMpOpenId(String openid);

    FsUser selectFsUserByUnionId(String unionId);


    FsUser selectFsUserByUserCode(String userCode);

    //CRM客户绑定 小程序客户之 查询小程序客户
    List<QwFsUserVO> selecQwFsUserListVO(QwFsUserParam qwFsUserParam);

    List<QwFsUserVO> selectQwFsUserListVO(QwFsUserParam qwFsUserParam);

    R clearUserVip(Long l);

    FsUser selectFsUserByUnionid(String unionId);

    List<FsUser> getUserListLimit(FsUser fsUser);

    List<FsUserPageListVO> selectFsUserPageList(FsUserPageListParam param);

    UserListPageVO getUserNumber(Long userId);

    UserDetailsVO getUserDetails(Long userId, Long fsUserId, String dateTag);

    Boolean disabledUser(String[] ids, boolean status);

    void transfer(FsUserTransferParamDTO param);

    /**
     * 查询销售会员总数,今日新增会员数
     * @param companyUserId 销售ID
     * @return map
     */
    Map<String, Long> getUserVipCountByCompanyUserId(Long companyUserId);

    FsUserSummaryCountVO userSummaryCount(Long userId);

    FsUserStatisticsVO userStatistics(Long userId, String startTime, String endTime, String courseId, String videoId);

    FsUserStatisticsVO userStatisticsDetails(Long userId, String courseId, String videoId);

    FsUserRankingVO userRanking(Long userId, String startTime, String endTime, String courseId, String videoId, String order, Integer type);

}
